@@ -303,7 +303,7 @@ class SFREAD:
                     return self.getobject(rel)
         return None
 
-    def getobject(self, obj, cal=False, nbeg=None, nend=None):
+    def getobject(self, obj, cal=False, copy=False, nbeg=None, nend=None):
         """
         Reads the data of a given TB, AB, SIG or SGR
         """
@@ -369,12 +369,16 @@ class SFREAD:
             else:
                 dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
 
+            dout.calib = False
 # Calibrated signals and signal groups
-            if cal:
-                dout = self.raw2calib(dout)
-                if self.diag in ('DCN', 'DCK', 'DCR'):
-                    dout.phys_unit = '1/m^2'
- 
+            if otyp in (6, 7):
+                if cal:
+                    dout = self.raw2calib(dout)
+                    if self.diag in ('DCN', 'DCK', 'DCR'):
+                        dout.phys_unit = '1/m^2'
+            if copy and (not dout.calib):
+                dout = dout*1 # create a copy of the read-only array
+
         return dout
 
 
@@ -429,6 +433,7 @@ class SFREAD:
 # assuming first entry wins
                     if j == 0:
                         dout = data*1. # Creates a copy of a read-only array, only once
+                        dout.calib = True
                     if (pscal[mult].size > 1):
                         pscal[mult] = pscal[mult][0]
                         pscal[shif] = pscal[shif][0]
